# Command-line tools, requires Rust
%bcond_without cli

Name:           drawpile
Version:        2.2.2
Release:        %mkrel 2
Summary:        A collaborative drawing program
Group:          Graphics/Editors and Converters
License:        GPLv3+
URL:            https://drawpile.net/
Source0:        https://github.com/drawpile/Drawpile/archive/%{version}/Drawpile-%{version}.tar.gz
# $ cargo vendor -s ../path/to/Cargo.toml
Source1:        vendor.tar.gz
Source2:        cargo_config
Patch0:         drawpile-fix-mandir.patch
BuildRequires:  cmake
BuildRequires:  cmake(ECM)
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  xdg-utils
BuildRequires:  qt6-qttranslations
BuildRequires:  cmake(KF6Archive)
BuildRequires:  cmake(Qt6Keychain)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6WebSockets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwebpdemux)
BuildRequires:  pkgconfig(libwebpmux)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(miniupnpc)
BuildRequires:  giflib-devel
%if %{with cli}
BuildRequires:  cargo-rpm-macros
%else
Obsoletes:      %{name}-cli < %{version}-%{release}
%endif

%description
DrawPile is a sketching oriented drawing program with a twist:
you can share your drawing live with other users.
There are no restrictions on who may draw where; every user has full access
to the whole picture simultaneously.

Feature highlights:
    * Antialiased drawing and multiple blending modes
    * Layers
    * Text annotations
    * Tablet pressure sensitivity
    * Image may be rotated freely while drawing
    * Built-in server for hosting shared sessions
    * Chat

%package server
Summary:        Dedicated Server for %{name}
Group:          Graphics/Editors and Converters
Conflicts:      %{name} < 2.2.2-2

%description server
Drawpile’s dedicated server is called drawpile-srv. It lets
you run your own server, just like pub.drawpile.net and other
community servers. It can be run on pretty much any kind of Linux
server, be it some cheap virtual server or even a Raspberry Pi.

%if %{with cli}
%package cli
Summary:        Command-line tools for %{name}
Group:          Graphics/Editors and Converters

%description cli
This package provides the command-line tools for %{name}
like dprectool, drawpile-cmd and drawpile-timelapse.
%endif

%prep
%autosetup -p1 -n Drawpile-%{version} -a1

%if %{with cli}
mkdir .cargo
cp %{SOURCE2} .cargo/config.toml
%endif

%build
%cmake_qt6 -DSERVER=ON \
           -DSERVERGUI=ON \
           -DINSTALL_DOC=ON \
           %{?with_cli:-DTOOLS=ON} \
           -DDISABLE_UPDATE_CHECK_DEFAULT=ON \
           -DCMAKE_INSTALL_MANDIR=%{_mandir}/man1
%cmake_build

%install
%cmake_install

#fix .desktop file
desktop-file-edit \
	--remove-category=Network \
		%{buildroot}%{_datadir}/applications/net.drawpile.drawpile.desktop

%files
%doc %{_docdir}/%{name}/
%{_bindir}/drawpile
%{_datadir}/drawpile/
%{_metainfodir}/net.drawpile.drawpile.appdata.xml
%{_datadir}/applications/net.drawpile.drawpile.desktop
%{_datadir}/mime/application/vnd.drawpile.recording.xml
%{_datadir}/mime/text/vnd.drawpile.recording.xml
%{_iconsdir}/hicolor/*/apps/drawpile*
%{_iconsdir}/hicolor/*/mimetypes/*

%files server
%doc doc/server-api.md
%{_bindir}/drawpile-srv
%{_mandir}/man1/drawpile-srv.1*

%files cli
%{_bindir}/dprectool
%{_bindir}/drawpile-cmd
%{_bindir}/drawpile-timelapse


%changelog
* Mon May 26 2025 daviddavid <daviddavid> 2.2.2-2.mga10
+ Revision: 2186560
- enable command-line tools support
- split out in their own sub-pkg the server and cli part

* Fri May 23 2025 daviddavid <daviddavid> 2.2.2-1.mga10
+ Revision: 2185863
- new version: 2.2.2 (mga#34298)
- switch to Qt6

* Sun May 04 2025 daviddavid <daviddavid> 2.1.20-2.mga10
+ Revision: 2180797
- rebuild for new miniupnpc 2.3.2

* Tue Sep 03 2024 daviddavid <daviddavid> 2.1.20-1.mga10
+ Revision: 2092953
- new version: 2.1.20
- add patch to fix build with miniupnpc 2.2.8
- rebuild for miniupnpc 2.2.8

* Wed Apr 06 2022 umeabot <umeabot> 2.1.17-3.mga9
+ Revision: 1845815
- Mageia 9 Mass Rebuild

* Wed Dec 16 2020 umeabot <umeabot> 2.1.17-2.mga8
+ Revision: 1658330
- Rebuild for new Qt5

* Sun Jul 26 2020 daviddavid <daviddavid> 2.1.17-1.mga8
+ Revision: 1609155
- new version: 2.1.17
- add patch to fix compatibility with libmicrohttpd 0.9.71
- add patch to fix build with Qt 5.15

* Sat Feb 15 2020 umeabot <umeabot> 2.0.10-4.mga8
+ Revision: 1524560
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sat Mar 30 2019 umeabot <umeabot> 2.0.10-3.mga7
+ Revision: 1381570
- Qt5 Rebuild

* Fri Aug 24 2018 daviddavid <daviddavid> 2.0.10-2.mga7
+ Revision: 1253804
- rebuild for new miniupnpc 2.1

* Sat May 05 2018 daviddavid <daviddavid> 2.0.10-1.mga7
+ Revision: 1226263
- new version: 2.0.10

* Sat Oct 21 2017 daviddavid <daviddavid> 2.0.5.1-1.mga7
+ Revision: 1172959
- new version: 2.0.5.1
- rebase Fix-desktop-etc-files-install patch
- remove merged upstream patch

* Tue May 16 2017 neoclust <neoclust> 1.0.2-9.mga6
+ Revision: 1102004
- Rebuild against new miniupnpc

* Sun Jan 10 2016 daviddavid <daviddavid> 1.0.2-8.mga6
+ Revision: 921192
- rebuild for new giflib 5.1.2

* Mon Dec 28 2015 daviddavid <daviddavid> 1.0.2-7.mga6
+ Revision: 916304
- rebuild for new libmicrohttpd 0.9.47

* Wed Oct 14 2015 wally <wally> 1.0.2-6.mga6
+ Revision: 891600
- remove Network category from .desktop file

* Wed Oct 14 2015 wally <wally> 1.0.2-5.mga6
+ Revision: 891527
- fix mimetype file install location

* Wed Oct 14 2015 wally <wally> 1.0.2-4.mga6
+ Revision: 891481
- fix mimetype icons installation also

* Wed Oct 14 2015 wally <wally> 1.0.2-3.mga6
+ Revision: 891461
- use upstream .desktop file
- add patch to install .desktop file, icons and mimetype properly
- BR giflib-devel
- BR miniupnpc-devel
- mageiafy .spec

* Tue Oct 13 2015 shlomif <shlomif> 1.0.2-2.mga6
+ Revision: 890492
- Add the .desktop file.
- Add missing BRs for i18n and stuff.
- Thanks to Necrosporus on Freenode.
- Update to new URL.

* Sun Oct 04 2015 shlomif <shlomif> 1.0.2-1.mga6
+ Revision: 886119
- Add missing BR
- Importing drawpile based on the openSUSE package


* Sat Oct  4 2014 mailaender@opensuse.org
- update to version 0.9.4
* Sun Dec 16 2012 mailaender@opensuse.org
- Adapt for SUSE
* Thu Feb  9 2012 huaren.zhong@gmail.com
- Rebuild for Fedora
  Sun Mar 28 00:00:00 UTC 2010 - Julian Aloofi <julian at, fedoraproject.org> 0.6.0-1
- initial package
